# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_trading_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$exchange/injective_trading_rpc.proto\x12\x15injective_trading_rpc\"\xb3\x01\n\x1cListTradingStrategiesRequest\x12\r\n\x05state\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x04 \x01(\t\x12\x12\n\nstart_time\x18\x05 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x12\x12\r\n\x05limit\x18\x07 \x01(\x11\x12\x0c\n\x04skip\x18\x08 \x01(\x04\"\x8a\x01\n\x1dListTradingStrategiesResponse\x12:\n\nstrategies\x18\x01 \x03(\x0b\x32&.injective_trading_rpc.TradingStrategy\x12-\n\x06paging\x18\x02 \x01(\x0b\x32\x1d.injective_trading_rpc.Paging\"\xea\x04\n\x0fTradingStrategy\x12\r\n\x05state\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x04 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x05 \x01(\t\x12\x17\n\x0f\x65xecution_price\x18\x06 \x01(\t\x12\x15\n\rbase_quantity\x18\x07 \x01(\t\x12\x16\n\x0equote_quantity\x18\x14 \x01(\t\x12\x13\n\x0blower_bound\x18\x08 \x01(\t\x12\x13\n\x0bupper_bound\x18\t \x01(\t\x12\x11\n\tstop_loss\x18\n \x01(\t\x12\x13\n\x0btake_profit\x18\x0b \x01(\t\x12\x10\n\x08swap_fee\x18\x0c \x01(\t\x12\x14\n\x0c\x62\x61se_deposit\x18\x11 \x01(\t\x12\x15\n\rquote_deposit\x18\x12 \x01(\t\x12\x18\n\x10market_mid_price\x18\x13 \x01(\t\x12#\n\x1bsubscription_quote_quantity\x18\x15 \x01(\t\x12\"\n\x1asubscription_base_quantity\x18\x16 \x01(\t\x12\x1d\n\x15number_of_grid_levels\x18\x17 \x01(\t\x12#\n\x1bshould_exit_with_quote_only\x18\x18 \x01(\x08\x12\x13\n\x0bstop_reason\x18\x19 \x01(\t\x12\x16\n\x0e\x63reated_height\x18\r \x01(\x12\x12\x16\n\x0eremoved_height\x18\x0e \x01(\x12\x12\x12\n\ncreated_at\x18\x0f \x01(\x12\x12\x12\n\nupdated_at\x18\x10 \x01(\x12\"\\\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\x12\x1b\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12\x12\x0c\n\x04next\x18\x05 \x03(\t2\x9a\x01\n\x13InjectiveTradingRPC\x12\x82\x01\n\x15ListTradingStrategies\x12\x33.injective_trading_rpc.ListTradingStrategiesRequest\x1a\x34.injective_trading_rpc.ListTradingStrategiesResponseB\x1aZ\x18/injective_trading_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_trading_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\030/injective_trading_rpcpb'
  _globals['_LISTTRADINGSTRATEGIESREQUEST']._serialized_start=64
  _globals['_LISTTRADINGSTRATEGIESREQUEST']._serialized_end=243
  _globals['_LISTTRADINGSTRATEGIESRESPONSE']._serialized_start=246
  _globals['_LISTTRADINGSTRATEGIESRESPONSE']._serialized_end=384
  _globals['_TRADINGSTRATEGY']._serialized_start=387
  _globals['_TRADINGSTRATEGY']._serialized_end=1005
  _globals['_PAGING']._serialized_start=1007
  _globals['_PAGING']._serialized_end=1099
  _globals['_INJECTIVETRADINGRPC']._serialized_start=1102
  _globals['_INJECTIVETRADINGRPC']._serialized_end=1256
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ibc.applications.interchain_accounts.controller.v1 import query_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query provides defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InterchainAccount = channel.unary_unary(
                '/ibc.applications.interchain_accounts.controller.v1.Query/InterchainAccount',
                request_serializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryInterchainAccountRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryInterchainAccountResponse.FromString,
                )
        self.Params = channel.unary_unary(
                '/ibc.applications.interchain_accounts.controller.v1.Query/Params',
                request_serializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                )


class QueryServicer(object):
    """Query provides defines the gRPC querier service.
    """

    def InterchainAccount(self, request, context):
        """InterchainAccount returns the interchain account address for a given owner address on a given connection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params queries all parameters of the ICA controller submodule.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InterchainAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.InterchainAccount,
                    request_deserializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryInterchainAccountRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryInterchainAccountResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.applications.interchain_accounts.controller.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query provides defines the gRPC querier service.
    """

    @staticmethod
    def InterchainAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.interchain_accounts.controller.v1.Query/InterchainAccount',
            ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryInterchainAccountRequest.SerializeToString,
            ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryInterchainAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.interchain_accounts.controller.v1.Query/Params',
            ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import os
from configparser import ConfigParser

GAS_PRICE = 500_000_000
GAS_FEE_BUFFER_AMOUNT = 25_000
MAX_MEMO_CHARACTERS = 256
ADDITIONAL_CHAIN_FORMAT_DECIMALS = 18
TICKER_TOKENS_SEPARATOR = "/"
INJ_DENOM = "inj"

devnet_config = ConfigParser()
devnet_config.read(os.path.join(os.path.dirname(__file__), "denoms_devnet.ini"))

testnet_config = ConfigParser()
testnet_config.read(os.path.join(os.path.dirname(__file__), "denoms_testnet.ini"))

mainnet_config = ConfigParser()
mainnet_config.read(os.path.join(os.path.dirname(__file__), "denoms_mainnet.ini"))

CONFIGS = {
    "devnet": devnet_config,
    "testnet": testnet_config,
    "mainnet": mainnet_config,
}



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/snapshots/v1beta1/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,cosmos/base/snapshots/v1beta1/snapshot.proto\x12\x1d\x63osmos.base.snapshots.v1beta1\x1a\x14gogoproto/gogo.proto\"\x89\x01\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12?\n\x08metadata\x18\x05 \x01(\x0b\x32\'.cosmos.base.snapshots.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\" \n\x08Metadata\x12\x14\n\x0c\x63hunk_hashes\x18\x01 \x03(\x0c\"\xd1\x03\n\x0cSnapshotItem\x12\x41\n\x05store\x18\x01 \x01(\x0b\x32\x30.cosmos.base.snapshots.v1beta1.SnapshotStoreItemH\x00\x12I\n\x04iavl\x18\x02 \x01(\x0b\x32/.cosmos.base.snapshots.v1beta1.SnapshotIAVLItemB\x08\xe2\xde\x1f\x04IAVLH\x00\x12I\n\textension\x18\x03 \x01(\x0b\x32\x34.cosmos.base.snapshots.v1beta1.SnapshotExtensionMetaH\x00\x12T\n\x11\x65xtension_payload\x18\x04 \x01(\x0b\x32\x37.cosmos.base.snapshots.v1beta1.SnapshotExtensionPayloadH\x00\x12\x45\n\x02kv\x18\x05 \x01(\x0b\x32-.cosmos.base.snapshots.v1beta1.SnapshotKVItemB\x08\x18\x01\xe2\xde\x1f\x02KVH\x00\x12\x43\n\x06schema\x18\x06 \x01(\x0b\x32-.cosmos.base.snapshots.v1beta1.SnapshotSchemaB\x02\x18\x01H\x00\x42\x06\n\x04item\"!\n\x11SnapshotStoreItem\x12\x0c\n\x04name\x18\x01 \x01(\t\"O\n\x10SnapshotIAVLItem\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0f\n\x07version\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x05\"5\n\x15SnapshotExtensionMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\"+\n\x18SnapshotExtensionPayload\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\"0\n\x0eSnapshotKVItem\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x18\x01\"\"\n\x0eSnapshotSchema\x12\x0c\n\x04keys\x18\x01 \x03(\x0c:\x02\x18\x01\x42.Z,github.com/cosmos/cosmos-sdk/snapshots/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.snapshots.v1beta1.snapshot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/snapshots/types'
  _SNAPSHOT.fields_by_name['metadata']._options = None
  _SNAPSHOT.fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _SNAPSHOTITEM.fields_by_name['iavl']._options = None
  _SNAPSHOTITEM.fields_by_name['iavl']._serialized_options = b'\342\336\037\004IAVL'
  _SNAPSHOTITEM.fields_by_name['kv']._options = None
  _SNAPSHOTITEM.fields_by_name['kv']._serialized_options = b'\030\001\342\336\037\002KV'
  _SNAPSHOTITEM.fields_by_name['schema']._options = None
  _SNAPSHOTITEM.fields_by_name['schema']._serialized_options = b'\030\001'
  _SNAPSHOTKVITEM._options = None
  _SNAPSHOTKVITEM._serialized_options = b'\030\001'
  _SNAPSHOTSCHEMA._options = None
  _SNAPSHOTSCHEMA._serialized_options = b'\030\001'
  _globals['_SNAPSHOT']._serialized_start=102
  _globals['_SNAPSHOT']._serialized_end=239
  _globals['_METADATA']._serialized_start=241
  _globals['_METADATA']._serialized_end=273
  _globals['_SNAPSHOTITEM']._serialized_start=276
  _globals['_SNAPSHOTITEM']._serialized_end=741
  _globals['_SNAPSHOTSTOREITEM']._serialized_start=743
  _globals['_SNAPSHOTSTOREITEM']._serialized_end=776
  _globals['_SNAPSHOTIAVLITEM']._serialized_start=778
  _globals['_SNAPSHOTIAVLITEM']._serialized_end=857
  _globals['_SNAPSHOTEXTENSIONMETA']._serialized_start=859
  _globals['_SNAPSHOTEXTENSIONMETA']._serialized_end=912
  _globals['_SNAPSHOTEXTENSIONPAYLOAD']._serialized_start=914
  _globals['_SNAPSHOTEXTENSIONPAYLOAD']._serialized_end=957
  _globals['_SNAPSHOTKVITEM']._serialized_start=959
  _globals['_SNAPSHOTKVITEM']._serialized_end=1007
  _globals['_SNAPSHOTSCHEMA']._serialized_start=1009
  _globals['_SNAPSHOTSCHEMA']._serialized_end=1043
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/nft/v1beta1/event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/nft/v1beta1/event.proto\x12\x12\x63osmos.nft.v1beta1\"K\n\tEventSend\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06sender\x18\x03 \x01(\t\x12\x10\n\x08receiver\x18\x04 \x01(\t\"8\n\tEventMint\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\"8\n\tEventBurn\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\tB$Z\"github.com/cosmos/cosmos-sdk/x/nftb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.v1beta1.event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/x/nft'
  _globals['_EVENTSEND']._serialized_start=54
  _globals['_EVENTSEND']._serialized_end=129
  _globals['_EVENTMINT']._serialized_start=131
  _globals['_EVENTMINT']._serialized_end=187
  _globals['_EVENTBURN']._serialized_start=189
  _globals['_EVENTBURN']._serialized_end=245
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ibc.applications.fee.v1 import query_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the ICS29 gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.IncentivizedPackets = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/IncentivizedPackets',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsResponse.FromString,
                )
        self.IncentivizedPacket = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/IncentivizedPacket',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketResponse.FromString,
                )
        self.IncentivizedPacketsForChannel = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/IncentivizedPacketsForChannel',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsForChannelRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsForChannelResponse.FromString,
                )
        self.TotalRecvFees = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/TotalRecvFees',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalRecvFeesRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalRecvFeesResponse.FromString,
                )
        self.TotalAckFees = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/TotalAckFees',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalAckFeesRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalAckFeesResponse.FromString,
                )
        self.TotalTimeoutFees = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/TotalTimeoutFees',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalTimeoutFeesRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalTimeoutFeesResponse.FromString,
                )
        self.Payee = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/Payee',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryPayeeRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryPayeeResponse.FromString,
                )
        self.CounterpartyPayee = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/CounterpartyPayee',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryCounterpartyPayeeRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryCounterpartyPayeeResponse.FromString,
                )
        self.FeeEnabledChannels = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/FeeEnabledChannels',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelsRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelsResponse.FromString,
                )
        self.FeeEnabledChannel = channel.unary_unary(
                '/ibc.applications.fee.v1.Query/FeeEnabledChannel',
                request_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelRequest.SerializeToString,
                response_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the ICS29 gRPC querier service.
    """

    def IncentivizedPackets(self, request, context):
        """IncentivizedPackets returns all incentivized packets and their associated fees
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IncentivizedPacket(self, request, context):
        """IncentivizedPacket returns all packet fees for a packet given its identifier
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IncentivizedPacketsForChannel(self, request, context):
        """Gets all incentivized packets for a specific channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalRecvFees(self, request, context):
        """TotalRecvFees returns the total receive fees for a packet given its identifier
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalAckFees(self, request, context):
        """TotalAckFees returns the total acknowledgement fees for a packet given its identifier
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalTimeoutFees(self, request, context):
        """TotalTimeoutFees returns the total timeout fees for a packet given its identifier
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Payee(self, request, context):
        """Payee returns the registered payee address for a specific channel given the relayer address
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CounterpartyPayee(self, request, context):
        """CounterpartyPayee returns the registered counterparty payee for forward relaying
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeeEnabledChannels(self, request, context):
        """FeeEnabledChannels returns a list of all fee enabled channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeeEnabledChannel(self, request, context):
        """FeeEnabledChannel returns true if the provided port and channel identifiers belong to a fee enabled channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'IncentivizedPackets': grpc.unary_unary_rpc_method_handler(
                    servicer.IncentivizedPackets,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsResponse.SerializeToString,
            ),
            'IncentivizedPacket': grpc.unary_unary_rpc_method_handler(
                    servicer.IncentivizedPacket,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketResponse.SerializeToString,
            ),
            'IncentivizedPacketsForChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.IncentivizedPacketsForChannel,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsForChannelRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsForChannelResponse.SerializeToString,
            ),
            'TotalRecvFees': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalRecvFees,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalRecvFeesRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalRecvFeesResponse.SerializeToString,
            ),
            'TotalAckFees': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalAckFees,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalAckFeesRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalAckFeesResponse.SerializeToString,
            ),
            'TotalTimeoutFees': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalTimeoutFees,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalTimeoutFeesRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalTimeoutFeesResponse.SerializeToString,
            ),
            'Payee': grpc.unary_unary_rpc_method_handler(
                    servicer.Payee,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryPayeeRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryPayeeResponse.SerializeToString,
            ),
            'CounterpartyPayee': grpc.unary_unary_rpc_method_handler(
                    servicer.CounterpartyPayee,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryCounterpartyPayeeRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryCounterpartyPayeeResponse.SerializeToString,
            ),
            'FeeEnabledChannels': grpc.unary_unary_rpc_method_handler(
                    servicer.FeeEnabledChannels,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelsRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelsResponse.SerializeToString,
            ),
            'FeeEnabledChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.FeeEnabledChannel,
                    request_deserializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelRequest.FromString,
                    response_serializer=ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.applications.fee.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the ICS29 gRPC querier service.
    """

    @staticmethod
    def IncentivizedPackets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/IncentivizedPackets',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IncentivizedPacket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/IncentivizedPacket',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IncentivizedPacketsForChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/IncentivizedPacketsForChannel',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsForChannelRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryIncentivizedPacketsForChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalRecvFees(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/TotalRecvFees',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalRecvFeesRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalRecvFeesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalAckFees(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/TotalAckFees',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalAckFeesRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalAckFeesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalTimeoutFees(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/TotalTimeoutFees',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalTimeoutFeesRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryTotalTimeoutFeesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Payee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/Payee',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryPayeeRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryPayeeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CounterpartyPayee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/CounterpartyPayee',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryCounterpartyPayeeRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryCounterpartyPayeeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeeEnabledChannels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/FeeEnabledChannels',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelsRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeeEnabledChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.fee.v1.Query/FeeEnabledChannel',
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelRequest.SerializeToString,
            ibc_dot_applications_dot_fee_dot_v1_dot_query__pb2.QueryFeeEnabledChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import math
from abc import ABC, abstractmethod
from decimal import Decimal
from typing import List, Optional

from google.protobuf import any_pb2

from pyinjective import PrivateKey, PublicKey, Transaction
from pyinjective.async_client import AsyncClient
from pyinjective.composer import Composer
from pyinjective.core.gas_limit_estimator import GasLimitEstimator
from pyinjective.core.network import Network


class BroadcasterAccountConfig(ABC):
    @property
    @abstractmethod
    def trading_injective_address(self) -> str:
        ...

    @property
    @abstractmethod
    def trading_private_key(self) -> PrivateKey:
        ...

    @property
    @abstractmethod
    def trading_public_key(self) -> PublicKey:
        ...

    @abstractmethod
    def messages_prepared_for_transaction(self, messages: List[any_pb2.Any]) -> List[any_pb2.Any]:
        ...


class TransactionFeeCalculator(ABC):
    DEFAULT_GAS_PRICE = 500_000_000

    @abstractmethod
    async def configure_gas_fee_for_transaction(
        self,
        transaction: Transaction,
        private_key: PrivateKey,
        public_key: PublicKey,
    ):
        ...


class MsgBroadcasterWithPk:
    def __init__(
        self,
        network: Network,
        account_config: BroadcasterAccountConfig,
        client: AsyncClient,
        composer: Composer,
        fee_calculator: TransactionFeeCalculator,
    ):
        self._network = network
        self._account_config = account_config
        self._client = client
        self._composer = composer
        self._fee_calculator = fee_calculator

    @classmethod
    def new_using_simulation(
        cls,
        network: Network,
        private_key: str,
        client: Optional[AsyncClient] = None,
        composer: Optional[Composer] = None,
    ):
        client = client or AsyncClient(network=network)
        composer = composer or Composer(network=client.network.string())
        account_config = StandardAccountBroadcasterConfig(private_key=private_key)
        fee_calculator = SimulatedTransactionFeeCalculator(client=client, composer=composer)
        instance = cls(
            network=network,
            account_config=account_config,
            client=client,
            composer=composer,
            fee_calculator=fee_calculator,
        )
        return instance

    @classmethod
    def new_without_simulation(
        cls,
        network: Network,
        private_key: str,
        client: Optional[AsyncClient] = None,
        composer: Optional[Composer] = None,
    ):
        client = client or AsyncClient(network=network)
        composer = composer or Composer(network=client.network.string())
        account_config = StandardAccountBroadcasterConfig(private_key=private_key)
        fee_calculator = MessageBasedTransactionFeeCalculator(client=client, composer=composer)
        instance = cls(
            network=network,
            account_config=account_config,
            client=client,
            composer=composer,
            fee_calculator=fee_calculator,
        )
        return instance

    @classmethod
    def new_for_grantee_account_using_simulation(
        cls,
        network: Network,
        grantee_private_key: str,
        client: Optional[AsyncClient] = None,
        composer: Optional[Composer] = None,
    ):
        client = client or AsyncClient(network=network)
        composer = composer or Composer(network=client.network.string())
        account_config = GranteeAccountBroadcasterConfig(grantee_private_key=grantee_private_key, composer=composer)
        fee_calculator = SimulatedTransactionFeeCalculator(client=client, composer=composer)
        instance = cls(
            network=network,
            account_config=account_config,
            client=client,
            composer=composer,
            fee_calculator=fee_calculator,
        )
        return instance

    @classmethod
    def new_for_grantee_account_without_simulation(
        cls,
        network: Network,
        grantee_private_key: str,
        client: Optional[AsyncClient] = None,
        composer: Optional[Composer] = None,
    ):
        client = client or AsyncClient(network=network)
        composer = composer or Composer(network=client.network.string())
        account_config = GranteeAccountBroadcasterConfig(grantee_private_key=grantee_private_key, composer=composer)
        fee_calculator = MessageBasedTransactionFeeCalculator(client=client, composer=composer)
        instance = cls(
            network=network,
            account_config=account_config,
            client=client,
            composer=composer,
            fee_calculator=fee_calculator,
        )
        return instance

    async def broadcast(self, messages: List[any_pb2.Any]):
        # Only force initialization of timeout_height and account info (number and sequence) if they are not initialized
        # Done this way to allow users to handle timeout_height and sequence re-synchronization in case of errors
        if self._client.timeout_height == 1:
            await self._client.sync_timeout_height()
        if self._client.number == 0:
            await self._client.get_account(self._account_config.trading_injective_address)

        messages_for_transaction = self._account_config.messages_prepared_for_transaction(messages=messages)

        transaction = Transaction()
        transaction.with_messages(*messages_for_transaction)
        transaction.with_sequence(self._client.get_sequence())
        transaction.with_account_num(self._client.get_number())
        transaction.with_chain_id(self._network.chain_id)

        await self._fee_calculator.configure_gas_fee_for_transaction(
            transaction=transaction,
            private_key=self._account_config.trading_private_key,
            public_key=self._account_config.trading_public_key,
        )
        transaction.with_memo("")
        transaction.with_timeout_height(timeout_height=self._client.timeout_height)

        sign_doc = transaction.get_sign_doc(self._account_config.trading_public_key)
        sig = self._account_config.trading_private_key.sign(sign_doc.SerializeToString())
        tx_raw_bytes = transaction.get_tx_data(sig, self._account_config.trading_public_key)

        # broadcast tx: send_tx_async_mode, send_tx_sync_mode
        transaction_result = await self._client.send_tx_sync_mode(tx_raw_bytes)

        return transaction_result


class StandardAccountBroadcasterConfig(BroadcasterAccountConfig):
    def __init__(self, private_key: str):
        self._private_key = PrivateKey.from_hex(private_key)
        self._public_key = self._private_key.to_public_key()
        self._address = self._public_key.to_address()

    @property
    def trading_injective_address(self) -> str:
        return self._address.to_acc_bech32()

    @property
    def trading_private_key(self) -> PrivateKey:
        return self._private_key

    @property
    def trading_public_key(self) -> PublicKey:
        return self._public_key

    def messages_prepared_for_transaction(self, messages: List[any_pb2.Any]) -> List[any_pb2.Any]:
        # For standard account the messages do not need to be addapted
        return messages


class GranteeAccountBroadcasterConfig(BroadcasterAccountConfig):
    def __init__(self, grantee_private_key: str, composer: Composer):
        self._grantee_private_key = PrivateKey.from_hex(grantee_private_key)
        self._grantee_public_key = self._grantee_private_key.to_public_key()
        self._grantee_address = self._grantee_public_key.to_address()
        self._composer = composer

    @property
    def trading_injective_address(self) -> str:
        return self._grantee_address.to_acc_bech32()

    @property
    def trading_private_key(self) -> PrivateKey:
        return self._grantee_private_key

    @property
    def trading_public_key(self) -> PublicKey:
        return self._grantee_public_key

    def messages_prepared_for_transaction(self, messages: List[any_pb2.Any]) -> List[any_pb2.Any]:
        exec_message = self._composer.MsgExec(
            grantee=self.trading_injective_address,
            msgs=messages,
        )

        return [exec_message]


class SimulatedTransactionFeeCalculator(TransactionFeeCalculator):
    def __init__(
        self,
        client: AsyncClient,
        composer: Composer,
        gas_price: Optional[int] = None,
        gas_limit_adjustment_multiplier: Optional[Decimal] = None,
    ):
        self._client = client
        self._composer = composer
        self._gas_price = gas_price or self.DEFAULT_GAS_PRICE
        self._gas_limit_adjustment_multiplier = gas_limit_adjustment_multiplier or Decimal("1.3")

    async def configure_gas_fee_for_transaction(
        self,
        transaction: Transaction,
        private_key: PrivateKey,
        public_key: PublicKey,
    ):
        sim_sign_doc = transaction.get_sign_doc(public_key)
        sim_sig = private_key.sign(sim_sign_doc.SerializeToString())
        sim_tx_raw_bytes = transaction.get_tx_data(sim_sig, public_key)

        # simulate tx
        (sim_res, success) = await self._client.simulate_tx(sim_tx_raw_bytes)
        if not success:
            raise RuntimeError(f"Transaction simulation error: {sim_res}")

        gas_limit = math.ceil(Decimal(str(sim_res.gas_info.gas_used)) * self._gas_limit_adjustment_multiplier)

        fee = [
            self._composer.Coin(
                amount=self._gas_price * gas_limit,
                denom=self._client.network.fee_denom,
            )
        ]

        transaction.with_gas(gas=gas_limit)
        transaction.with_fee(fee=fee)


class MessageBasedTransactionFeeCalculator(TransactionFeeCalculator):
    TRANSACTION_GAS_LIMIT = 60_000

    def __init__(self, client: AsyncClient, composer: Composer, gas_price: Optional[int] = None):
        self._client = client
        self._composer = composer
        self._gas_price = gas_price or self.DEFAULT_GAS_PRICE

    async def configure_gas_fee_for_transaction(
        self,
        transaction: Transaction,
        private_key: PrivateKey,
        public_key: PublicKey,
    ):
        messages_gas_limit = math.ceil(self._calculate_gas_limit(messages=transaction.msgs))
        transaction_gas_limit = messages_gas_limit + self.TRANSACTION_GAS_LIMIT

        fee = [
            self._composer.Coin(
                amount=math.ceil(self._gas_price * transaction_gas_limit),
                denom=self._client.network.fee_denom,
            )
        ]

        transaction.with_gas(gas=transaction_gas_limit)
        transaction.with_fee(fee=fee)

    def _message_type(self, message: any_pb2.Any) -> str:
        if isinstance(message, any_pb2.Any):
            message_type = message.type_url
        else:
            message_type = message.DESCRIPTOR.full_name
        return message_type

    def _calculate_gas_limit(self, messages: List[any_pb2.Any]) -> int:
        total_gas_limit = Decimal("0")

        for message in messages:
            estimator = GasLimitEstimator.for_message(message=message)
            total_gas_limit += estimator.gas_limit()

        return math.ceil(total_gas_limit)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/auth/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/auth/v1beta1/tx.proto\x12\x13\x63osmos.auth.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\"\xac\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32\x1b.cosmos.auth.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:4\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*!cosmos-sdk/x/auth/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2p\n\x03Msg\x12\x62\n\x0cUpdateParams\x12$.cosmos.auth.v1beta1.MsgUpdateParams\x1a,.cosmos.auth.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42+Z)github.com/cosmos/cosmos-sdk/x/auth/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/auth/types'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority\212\347\260*!cosmos-sdk/x/auth/MsgUpdateParams'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=179
  _globals['_MSGUPDATEPARAMS']._serialized_end=351
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=353
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=378
  _globals['_MSG']._serialized_start=380
  _globals['_MSG']._serialized_end=492
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.crypto.multisig.v1beta1 import multisig_pb2 as cosmos_dot_crypto_dot_multisig_dot_v1beta1_dot_multisig__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.tx.signing.v1beta1 import signing_pb2 as cosmos_dot_tx_dot_signing_dot_v1beta1_dot_signing__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63osmos/tx/v1beta1/tx.proto\x12\x11\x63osmos.tx.v1beta1\x1a\x14gogoproto/gogo.proto\x1a-cosmos/crypto/multisig/v1beta1/multisig.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\'cosmos/tx/signing/v1beta1/signing.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"q\n\x02Tx\x12\'\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x19.cosmos.tx.v1beta1.TxBody\x12.\n\tauth_info\x18\x02 \x01(\x0b\x32\x1b.cosmos.tx.v1beta1.AuthInfo\x12\x12\n\nsignatures\x18\x03 \x03(\x0c\"H\n\x05TxRaw\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61uth_info_bytes\x18\x02 \x01(\x0c\x12\x12\n\nsignatures\x18\x03 \x03(\x0c\"`\n\x07SignDoc\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61uth_info_bytes\x18\x02 \x01(\x0c\x12\x10\n\x08\x63hain_id\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x04 \x01(\x04\"\xb1\x01\n\x10SignDocDirectAux\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12(\n\npublic_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x10\n\x08\x63hain_id\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x04 \x01(\x04\x12\x10\n\x08sequence\x18\x05 \x01(\x04\x12#\n\x03tip\x18\x06 \x01(\x0b\x32\x16.cosmos.tx.v1beta1.Tip\"\xc7\x01\n\x06TxBody\x12&\n\x08messages\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04memo\x18\x02 \x01(\t\x12\x16\n\x0etimeout_height\x18\x03 \x01(\x04\x12\x30\n\x11\x65xtension_options\x18\xff\x07 \x03(\x0b\x32\x14.google.protobuf.Any\x12=\n\x1enon_critical_extension_options\x18\xff\x0f \x03(\x0b\x32\x14.google.protobuf.Any\"\x89\x01\n\x08\x41uthInfo\x12\x33\n\x0csigner_infos\x18\x01 \x03(\x0b\x32\x1d.cosmos.tx.v1beta1.SignerInfo\x12#\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\x16.cosmos.tx.v1beta1.Fee\x12#\n\x03tip\x18\x03 \x01(\x0b\x32\x16.cosmos.tx.v1beta1.Tip\"x\n\nSignerInfo\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12.\n\tmode_info\x18\x02 \x01(\x0b\x32\x1b.cosmos.tx.v1beta1.ModeInfo\x12\x10\n\x08sequence\x18\x03 \x01(\x04\"\xb5\x02\n\x08ModeInfo\x12\x34\n\x06single\x18\x01 \x01(\x0b\x32\".cosmos.tx.v1beta1.ModeInfo.SingleH\x00\x12\x32\n\x05multi\x18\x02 \x01(\x0b\x32!.cosmos.tx.v1beta1.ModeInfo.MultiH\x00\x1a;\n\x06Single\x12\x31\n\x04mode\x18\x01 \x01(\x0e\x32#.cosmos.tx.signing.v1beta1.SignMode\x1a{\n\x05Multi\x12\x41\n\x08\x62itarray\x18\x01 \x01(\x0b\x32/.cosmos.crypto.multisig.v1beta1.CompactBitArray\x12/\n\nmode_infos\x18\x02 \x03(\x0b\x32\x1b.cosmos.tx.v1beta1.ModeInfoB\x05\n\x03sum\"\xc9\x01\n\x03\x46\x65\x65\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\'\n\x05payer\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x07granter\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x8c\x01\n\x03Tip\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12(\n\x06tipper\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\xb1\x01\n\rAuxSignerData\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x08sign_doc\x18\x02 \x01(\x0b\x32#.cosmos.tx.v1beta1.SignDocDirectAux\x12\x31\n\x04mode\x18\x03 \x01(\x0e\x32#.cosmos.tx.signing.v1beta1.SignMode\x12\x0b\n\x03sig\x18\x04 \x01(\x0c\x42\'Z%github.com/cosmos/cosmos-sdk/types/txb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z%github.com/cosmos/cosmos-sdk/types/tx'
  _FEE.fields_by_name['amount']._options = None
  _FEE.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _FEE.fields_by_name['payer']._options = None
  _FEE.fields_by_name['payer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _FEE.fields_by_name['granter']._options = None
  _FEE.fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _TIP.fields_by_name['amount']._options = None
  _TIP.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _TIP.fields_by_name['tipper']._options = None
  _TIP.fields_by_name['tipper']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _AUXSIGNERDATA.fields_by_name['address']._options = None
  _AUXSIGNERDATA.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_TX']._serialized_start=245
  _globals['_TX']._serialized_end=358
  _globals['_TXRAW']._serialized_start=360
  _globals['_TXRAW']._serialized_end=432
  _globals['_SIGNDOC']._serialized_start=434
  _globals['_SIGNDOC']._serialized_end=530
  _globals['_SIGNDOCDIRECTAUX']._serialized_start=533
  _globals['_SIGNDOCDIRECTAUX']._serialized_end=710
  _globals['_TXBODY']._serialized_start=713
  _globals['_TXBODY']._serialized_end=912
  _globals['_AUTHINFO']._serialized_start=915
  _globals['_AUTHINFO']._serialized_end=1052
  _globals['_SIGNERINFO']._serialized_start=1054
  _globals['_SIGNERINFO']._serialized_end=1174
  _globals['_MODEINFO']._serialized_start=1177
  _globals['_MODEINFO']._serialized_end=1486
  _globals['_MODEINFO_SINGLE']._serialized_start=1295
  _globals['_MODEINFO_SINGLE']._serialized_end=1354
  _globals['_MODEINFO_MULTI']._serialized_start=1356
  _globals['_MODEINFO_MULTI']._serialized_end=1479
  _globals['_FEE']._serialized_start=1489
  _globals['_FEE']._serialized_end=1690
  _globals['_TIP']._serialized_start=1693
  _globals['_TIP']._serialized_end=1833
  _globals['_AUXSIGNERDATA']._serialized_start=1836
  _globals['_AUXSIGNERDATA']._serialized_end=2013
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1/gov.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63osmos/gov/v1/gov.proto\x12\rcosmos.gov.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"_\n\x12WeightedVoteOption\x12)\n\x06option\x18\x01 \x01(\x0e\x32\x19.cosmos.gov.v1.VoteOption\x12\x1e\n\x06weight\x18\x02 \x01(\tB\x0e\xd2\xb4-\ncosmos.Dec\"\x81\x01\n\x07\x44\x65posit\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\xab\x04\n\x08Proposal\x12\n\n\x02id\x18\x01 \x01(\x04\x12&\n\x08messages\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12-\n\x06status\x18\x03 \x01(\x0e\x32\x1d.cosmos.gov.v1.ProposalStatus\x12\x36\n\x12\x66inal_tally_result\x18\x04 \x01(\x0b\x32\x1a.cosmos.gov.v1.TallyResult\x12\x35\n\x0bsubmit_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12:\n\x10\x64\x65posit_end_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12;\n\rtotal_deposit\x18\x07 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\x11voting_start_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x39\n\x0fvoting_end_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x10\n\x08metadata\x18\n \x01(\t\x12\r\n\x05title\x18\x0b \x01(\t\x12\x0f\n\x07summary\x18\x0c \x01(\t\x12*\n\x08proposer\x18\r \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\xa5\x01\n\x0bTallyResult\x12!\n\tyes_count\x18\x01 \x01(\tB\x0e\xd2\xb4-\ncosmos.Int\x12%\n\rabstain_count\x18\x02 \x01(\tB\x0e\xd2\xb4-\ncosmos.Int\x12 \n\x08no_count\x18\x03 \x01(\tB\x0e\xd2\xb4-\ncosmos.Int\x12*\n\x12no_with_veto_count\x18\x04 \x01(\tB\x0e\xd2\xb4-\ncosmos.Int\"\x90\x01\n\x04Vote\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x07options\x18\x04 \x03(\x0b\x32!.cosmos.gov.v1.WeightedVoteOption\x12\x10\n\x08metadata\x18\x05 \x01(\tJ\x04\x08\x03\x10\x04\"\xbb\x01\n\rDepositParams\x12M\n\x0bmin_deposit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1d\xc8\xde\x1f\x00\xea\xde\x1f\x15min_deposit,omitempty\x12[\n\x12max_deposit_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB$\xea\xde\x1f\x1cmax_deposit_period,omitempty\x98\xdf\x1f\x01\"F\n\x0cVotingParams\x12\x36\n\rvoting_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01\"x\n\x0bTallyParams\x12\x1e\n\x06quorum\x18\x01 \x01(\tB\x0e\xd2\xb4-\ncosmos.Dec\x12!\n\tthreshold\x18\x02 \x01(\tB\x0e\xd2\xb4-\ncosmos.Dec\x12&\n\x0eveto_threshold\x18\x03 \x01(\tB\x0e\xd2\xb4-\ncosmos.Dec\"\xaf\x03\n\x06Params\x12\x39\n\x0bmin_deposit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\x12max_deposit_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01\x12\x36\n\rvoting_period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01\x12\x1e\n\x06quorum\x18\x04 \x01(\tB\x0e\xd2\xb4-\ncosmos.Dec\x12!\n\tthreshold\x18\x05 \x01(\tB\x0e\xd2\xb4-\ncosmos.Dec\x12&\n\x0eveto_threshold\x18\x06 \x01(\tB\x0e\xd2\xb4-\ncosmos.Dec\x12\x31\n\x19min_initial_deposit_ratio\x18\x07 \x01(\tB\x0e\xd2\xb4-\ncosmos.Dec\x12\x18\n\x10\x62urn_vote_quorum\x18\r \x01(\x08\x12%\n\x1d\x62urn_proposal_deposit_prevote\x18\x0e \x01(\x08\x12\x16\n\x0e\x62urn_vote_veto\x18\x0f \x01(\x08*\x89\x01\n\nVoteOption\x12\x1b\n\x17VOTE_OPTION_UNSPECIFIED\x10\x00\x12\x13\n\x0fVOTE_OPTION_YES\x10\x01\x12\x17\n\x13VOTE_OPTION_ABSTAIN\x10\x02\x12\x12\n\x0eVOTE_OPTION_NO\x10\x03\x12\x1c\n\x18VOTE_OPTION_NO_WITH_VETO\x10\x04*\xce\x01\n\x0eProposalStatus\x12\x1f\n\x1bPROPOSAL_STATUS_UNSPECIFIED\x10\x00\x12\"\n\x1ePROPOSAL_STATUS_DEPOSIT_PERIOD\x10\x01\x12!\n\x1dPROPOSAL_STATUS_VOTING_PERIOD\x10\x02\x12\x1a\n\x16PROPOSAL_STATUS_PASSED\x10\x03\x12\x1c\n\x18PROPOSAL_STATUS_REJECTED\x10\x04\x12\x1a\n\x16PROPOSAL_STATUS_FAILED\x10\x05\x42-Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1.gov_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1'
  _WEIGHTEDVOTEOPTION.fields_by_name['weight']._options = None
  _WEIGHTEDVOTEOPTION.fields_by_name['weight']._serialized_options = b'\322\264-\ncosmos.Dec'
  _DEPOSIT.fields_by_name['depositor']._options = None
  _DEPOSIT.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DEPOSIT.fields_by_name['amount']._options = None
  _DEPOSIT.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _PROPOSAL.fields_by_name['submit_time']._options = None
  _PROPOSAL.fields_by_name['submit_time']._serialized_options = b'\220\337\037\001'
  _PROPOSAL.fields_by_name['deposit_end_time']._options = None
  _PROPOSAL.fields_by_name['deposit_end_time']._serialized_options = b'\220\337\037\001'
  _PROPOSAL.fields_by_name['total_deposit']._options = None
  _PROPOSAL.fields_by_name['total_deposit']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _PROPOSAL.fields_by_name['voting_start_time']._options = None
  _PROPOSAL.fields_by_name['voting_start_time']._serialized_options = b'\220\337\037\001'
  _PROPOSAL.fields_by_name['voting_end_time']._options = None
  _PROPOSAL.fields_by_name['voting_end_time']._serialized_options = b'\220\337\037\001'
  _PROPOSAL.fields_by_name['proposer']._options = None
  _PROPOSAL.fields_by_name['proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _TALLYRESULT.fields_by_name['yes_count']._options = None
  _TALLYRESULT.fields_by_name['yes_count']._serialized_options = b'\322\264-\ncosmos.Int'
  _TALLYRESULT.fields_by_name['abstain_count']._options = None
  _TALLYRESULT.fields_by_name['abstain_count']._serialized_options = b'\322\264-\ncosmos.Int'
  _TALLYRESULT.fields_by_name['no_count']._options = None
  _TALLYRESULT.fields_by_name['no_count']._serialized_options = b'\322\264-\ncosmos.Int'
  _TALLYRESULT.fields_by_name['no_with_veto_count']._options = None
  _TALLYRESULT.fields_by_name['no_with_veto_count']._serialized_options = b'\322\264-\ncosmos.Int'
  _VOTE.fields_by_name['voter']._options = None
  _VOTE.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DEPOSITPARAMS.fields_by_name['min_deposit']._options = None
  _DEPOSITPARAMS.fields_by_name['min_deposit']._serialized_options = b'\310\336\037\000\352\336\037\025min_deposit,omitempty'
  _DEPOSITPARAMS.fields_by_name['max_deposit_period']._options = None
  _DEPOSITPARAMS.fields_by_name['max_deposit_period']._serialized_options = b'\352\336\037\034max_deposit_period,omitempty\230\337\037\001'
  _VOTINGPARAMS.fields_by_name['voting_period']._options = None
  _VOTINGPARAMS.fields_by_name['voting_period']._serialized_options = b'\230\337\037\001'
  _TALLYPARAMS.fields_by_name['quorum']._options = None
  _TALLYPARAMS.fields_by_name['quorum']._serialized_options = b'\322\264-\ncosmos.Dec'
  _TALLYPARAMS.fields_by_name['threshold']._options = None
  _TALLYPARAMS.fields_by_name['threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _TALLYPARAMS.fields_by_name['veto_threshold']._options = None
  _TALLYPARAMS.fields_by_name['veto_threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['min_deposit']._options = None
  _PARAMS.fields_by_name['min_deposit']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _PARAMS.fields_by_name['max_deposit_period']._options = None
  _PARAMS.fields_by_name['max_deposit_period']._serialized_options = b'\230\337\037\001'
  _PARAMS.fields_by_name['voting_period']._options = None
  _PARAMS.fields_by_name['voting_period']._serialized_options = b'\230\337\037\001'
  _PARAMS.fields_by_name['quorum']._options = None
  _PARAMS.fields_by_name['quorum']._serialized_options = b'\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['threshold']._options = None
  _PARAMS.fields_by_name['threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['veto_threshold']._options = None
  _PARAMS.fields_by_name['veto_threshold']._serialized_options = b'\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['min_initial_deposit_ratio']._options = None
  _PARAMS.fields_by_name['min_initial_deposit_ratio']._serialized_options = b'\322\264-\ncosmos.Dec'
  _globals['_VOTEOPTION']._serialized_start=2155
  _globals['_VOTEOPTION']._serialized_end=2292
  _globals['_PROPOSALSTATUS']._serialized_start=2295
  _globals['_PROPOSALSTATUS']._serialized_end=2501
  _globals['_WEIGHTEDVOTEOPTION']._serialized_start=234
  _globals['_WEIGHTEDVOTEOPTION']._serialized_end=329
  _globals['_DEPOSIT']._serialized_start=332
  _globals['_DEPOSIT']._serialized_end=461
  _globals['_PROPOSAL']._serialized_start=464
  _globals['_PROPOSAL']._serialized_end=1019
  _globals['_TALLYRESULT']._serialized_start=1022
  _globals['_TALLYRESULT']._serialized_end=1187
  _globals['_VOTE']._serialized_start=1190
  _globals['_VOTE']._serialized_end=1334
  _globals['_DEPOSITPARAMS']._serialized_start=1337
  _globals['_DEPOSITPARAMS']._serialized_end=1524
  _globals['_VOTINGPARAMS']._serialized_start=1526
  _globals['_VOTINGPARAMS']._serialized_end=1596
  _globals['_TALLYPARAMS']._serialized_start=1598
  _globals['_TALLYPARAMS']._serialized_end=1718
  _globals['_PARAMS']._serialized_start=1721
  _globals['_PARAMS']._serialized_end=2152
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from injective.wasmx.v1 import query_pb2 as injective_dot_wasmx_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WasmxParams = channel.unary_unary(
                '/injective.wasmx.v1.Query/WasmxParams',
                request_serializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryWasmxParamsRequest.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryWasmxParamsResponse.FromString,
                )
        self.ContractRegistrationInfo = channel.unary_unary(
                '/injective.wasmx.v1.Query/ContractRegistrationInfo',
                request_serializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryContractRegistrationInfoRequest.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryContractRegistrationInfoResponse.FromString,
                )
        self.WasmxModuleState = channel.unary_unary(
                '/injective.wasmx.v1.Query/WasmxModuleState',
                request_serializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryModuleStateResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def WasmxParams(self, request, context):
        """Retrieves wasmx params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ContractRegistrationInfo(self, request, context):
        """Retrieves contract registration info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WasmxModuleState(self, request, context):
        """Retrieves the entire wasmx module's state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WasmxParams': grpc.unary_unary_rpc_method_handler(
                    servicer.WasmxParams,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryWasmxParamsRequest.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryWasmxParamsResponse.SerializeToString,
            ),
            'ContractRegistrationInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ContractRegistrationInfo,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryContractRegistrationInfoRequest.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryContractRegistrationInfoResponse.SerializeToString,
            ),
            'WasmxModuleState': grpc.unary_unary_rpc_method_handler(
                    servicer.WasmxModuleState,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryModuleStateRequest.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_query__pb2.QueryModuleStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.wasmx.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def WasmxParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Query/WasmxParams',
            injective_dot_wasmx_dot_v1_dot_query__pb2.QueryWasmxParamsRequest.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_query__pb2.QueryWasmxParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ContractRegistrationInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Query/ContractRegistrationInfo',
            injective_dot_wasmx_dot_v1_dot_query__pb2.QueryContractRegistrationInfoRequest.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_query__pb2.QueryContractRegistrationInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WasmxModuleState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Query/WasmxModuleState',
            injective_dot_wasmx_dot_v1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_query__pb2.QueryModuleStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/staking.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from amino import amino_pb2 as amino_dot_amino__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/staking.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\x1a\x1ctendermint/types/types.proto\x1a\x1btendermint/abci/types.proto\"\x83\x01\n\x0eHistoricalInfo\x12\x33\n\x06header\x18\x01 \x01(\x0b\x32\x18.tendermint.types.HeaderB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12<\n\x06valset\x18\x02 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x8e\x02\n\x0f\x43ommissionRates\x12J\n\x04rate\x18\x01 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12N\n\x08max_rate\x18\x02 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12U\n\x0fmax_change_rate\x18\x03 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\"\xa8\x01\n\nCommission\x12P\n\x10\x63ommission_rates\x18\x01 \x01(\x0b\x32\'.cosmos.staking.v1beta1.CommissionRatesB\r\xc8\xde\x1f\x00\xd0\xde\x1f\x01\xa8\xe7\xb0*\x01\x12>\n\x0bupdate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\"v\n\x0b\x44\x65scription\x12\x0f\n\x07moniker\x18\x01 \x01(\t\x12\x10\n\x08identity\x18\x02 \x01(\t\x12\x0f\n\x07website\x18\x03 \x01(\t\x12\x18\n\x10security_contact\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\"\xfd\x05\n\tValidator\x12\x32\n\x10operator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12H\n\x10\x63onsensus_pubkey\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x18\xca\xb4-\x14\x63osmos.crypto.PubKey\x12\x0e\n\x06jailed\x18\x03 \x01(\x08\x12\x32\n\x06status\x18\x04 \x01(\x0e\x32\".cosmos.staking.v1beta1.BondStatus\x12L\n\x06tokens\x18\x05 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xd2\xb4-\ncosmos.Int\x12V\n\x10\x64\x65legator_shares\x18\x06 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12\x43\n\x0b\x64\x65scription\x18\x07 \x01(\x0b\x32#.cosmos.staking.v1beta1.DescriptionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x18\n\x10unbonding_height\x18\x08 \x01(\x03\x12\x41\n\x0eunbonding_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x41\n\ncommission\x18\n \x01(\x0b\x32\".cosmos.staking.v1beta1.CommissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12Y\n\x13min_self_delegation\x18\x0b \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xd2\xb4-\ncosmos.Int\x12#\n\x1bunbonding_on_hold_ref_count\x18\x0c \x01(\x03\x12\x15\n\runbonding_ids\x18\r \x03(\x04:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"E\n\x0cValAddresses\x12+\n\taddresses\x18\x01 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x08\x98\xa0\x1f\x00\x80\xdc \x01\"\x80\x01\n\x06\x44VPair\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x11validator_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"C\n\x07\x44VPairs\x12\x38\n\x05pairs\x18\x01 \x03(\x0b\x32\x1e.cosmos.staking.v1beta1.DVPairB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\xc1\x01\n\nDVVTriplet\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x37\n\x15validator_src_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x37\n\x15validator_dst_address\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"N\n\x0b\x44VVTriplets\x12?\n\x08triplets\x18\x01 \x03(\x0b\x32\".cosmos.staking.v1beta1.DVVTripletB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\xd2\x01\n\nDelegation\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x11validator_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12L\n\x06shares\x18\x03 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xdb\x01\n\x13UnbondingDelegation\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x11validator_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12L\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x30.cosmos.staking.v1beta1.UnbondingDelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xe2\x02\n\x18UnbondingDelegationEntry\x12\x17\n\x0f\x63reation_height\x18\x01 \x01(\x03\x12\x42\n\x0f\x63ompletion_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12U\n\x0finitial_balance\x18\x03 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xd2\xb4-\ncosmos.Int\x12M\n\x07\x62\x61lance\x18\x04 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xd2\xb4-\ncosmos.Int\x12\x14\n\x0cunbonding_id\x18\x05 \x01(\x04\x12#\n\x1bunbonding_on_hold_ref_count\x18\x06 \x01(\x03:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\"\xde\x02\n\x11RedelegationEntry\x12\x17\n\x0f\x63reation_height\x18\x01 \x01(\x03\x12\x42\n\x0f\x63ompletion_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12U\n\x0finitial_balance\x18\x03 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xd2\xb4-\ncosmos.Int\x12P\n\nshares_dst\x18\x04 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12\x14\n\x0cunbonding_id\x18\x05 \x01(\x04\x12#\n\x1bunbonding_on_hold_ref_count\x18\x06 \x01(\x03:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\"\x8a\x02\n\x0cRedelegation\x12\x33\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x37\n\x15validator_src_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x37\n\x15validator_dst_address\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x45\n\x07\x65ntries\x18\x04 \x03(\x0b\x32).cosmos.staking.v1beta1.RedelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xbc\x02\n\x06Params\x12@\n\x0eunbonding_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x16\n\x0emax_validators\x18\x02 \x01(\r\x12\x13\n\x0bmax_entries\x18\x03 \x01(\r\x12\x1a\n\x12historical_entries\x18\x04 \x01(\r\x12\x12\n\nbond_denom\x18\x05 \x01(\t\x12i\n\x13min_commission_rate\x18\x06 \x01(\tBL\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x1ayaml:\"min_commission_rate\":(\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x1b\x63osmos-sdk/x/staking/Params\"\x98\x01\n\x12\x44\x65legationResponse\x12\x41\n\ndelegation\x18\x01 \x01(\x0b\x32\".cosmos.staking.v1beta1.DelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x35\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xc2\x01\n\x19RedelegationEntryResponse\x12P\n\x12redelegation_entry\x18\x01 \x01(\x0b\x32).cosmos.staking.v1beta1.RedelegationEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12M\n\x07\x62\x61lance\x18\x04 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xd2\xb4-\ncosmos.Int:\x04\xe8\xa0\x1f\x01\"\xb2\x01\n\x14RedelegationResponse\x12\x45\n\x0credelegation\x18\x01 \x01(\x0b\x32$.cosmos.staking.v1beta1.RedelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12M\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x31.cosmos.staking.v1beta1.RedelegationEntryResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x00\"\xee\x01\n\x04Pool\x12q\n\x11not_bonded_tokens\x18\x01 \x01(\tBV\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xea\xde\x1f\x11not_bonded_tokens\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01\x12i\n\rbonded_tokens\x18\x02 \x01(\tBR\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xea\xde\x1f\rbonded_tokens\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01:\x08\xe8\xa0\x1f\x01\xf0\xa0\x1f\x01\"P\n\x10ValidatorUpdates\x12<\n\x07updates\x18\x01 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01*\xb6\x01\n\nBondStatus\x12,\n\x17\x42OND_STATUS_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUnspecified\x12&\n\x14\x42OND_STATUS_UNBONDED\x10\x01\x1a\x0c\x8a\x9d \x08Unbonded\x12(\n\x15\x42OND_STATUS_UNBONDING\x10\x02\x1a\r\x8a\x9d \tUnbonding\x12\"\n\x12\x42OND_STATUS_BONDED\x10\x03\x1a\n\x8a\x9d \x06\x42onded\x1a\x04\x88\xa3\x1e\x00*]\n\nInfraction\x12\x1a\n\x16INFRACTION_UNSPECIFIED\x10\x00\x12\x1a\n\x16INFRACTION_DOUBLE_SIGN\x10\x01\x12\x17\n\x13INFRACTION_DOWNTIME\x10\x02\x42.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.staking_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _BONDSTATUS._options = None
  _BONDSTATUS._serialized_options = b'\210\243\036\000'
  _BONDSTATUS.values_by_name["BOND_STATUS_UNSPECIFIED"]._options = None
  _BONDSTATUS.values_by_name["BOND_STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \013Unspecified'
  _BONDSTATUS.values_by_name["BOND_STATUS_UNBONDED"]._options = None
  _BONDSTATUS.values_by_name["BOND_STATUS_UNBONDED"]._serialized_options = b'\212\235 \010Unbonded'
  _BONDSTATUS.values_by_name["BOND_STATUS_UNBONDING"]._options = None
  _BONDSTATUS.values_by_name["BOND_STATUS_UNBONDING"]._serialized_options = b'\212\235 \tUnbonding'
  _BONDSTATUS.values_by_name["BOND_STATUS_BONDED"]._options = None
  _BONDSTATUS.values_by_name["BOND_STATUS_BONDED"]._serialized_options = b'\212\235 \006Bonded'
  _HISTORICALINFO.fields_by_name['header']._options = None
  _HISTORICALINFO.fields_by_name['header']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _HISTORICALINFO.fields_by_name['valset']._options = None
  _HISTORICALINFO.fields_by_name['valset']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _COMMISSIONRATES.fields_by_name['rate']._options = None
  _COMMISSIONRATES.fields_by_name['rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _COMMISSIONRATES.fields_by_name['max_rate']._options = None
  _COMMISSIONRATES.fields_by_name['max_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _COMMISSIONRATES.fields_by_name['max_change_rate']._options = None
  _COMMISSIONRATES.fields_by_name['max_change_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _COMMISSIONRATES._options = None
  _COMMISSIONRATES._serialized_options = b'\230\240\037\000\350\240\037\001'
  _COMMISSION.fields_by_name['commission_rates']._options = None
  _COMMISSION.fields_by_name['commission_rates']._serialized_options = b'\310\336\037\000\320\336\037\001\250\347\260*\001'
  _COMMISSION.fields_by_name['update_time']._options = None
  _COMMISSION.fields_by_name['update_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _COMMISSION._options = None
  _COMMISSION._serialized_options = b'\230\240\037\000\350\240\037\001'
  _DESCRIPTION._options = None
  _DESCRIPTION._serialized_options = b'\230\240\037\000\350\240\037\001'
  _VALIDATOR.fields_by_name['operator_address']._options = None
  _VALIDATOR.fields_by_name['operator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _VALIDATOR.fields_by_name['consensus_pubkey']._options = None
  _VALIDATOR.fields_by_name['consensus_pubkey']._serialized_options = b'\312\264-\024cosmos.crypto.PubKey'
  _VALIDATOR.fields_by_name['tokens']._options = None
  _VALIDATOR.fields_by_name['tokens']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\322\264-\ncosmos.Int'
  _VALIDATOR.fields_by_name['delegator_shares']._options = None
  _VALIDATOR.fields_by_name['delegator_shares']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _VALIDATOR.fields_by_name['description']._options = None
  _VALIDATOR.fields_by_name['description']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _VALIDATOR.fields_by_name['unbonding_time']._options = None
  _VALIDATOR.fields_by_name['unbonding_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _VALIDATOR.fields_by_name['commission']._options = None
  _VALIDATOR.fields_by_name['commission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _VALIDATOR.fields_by_name['min_self_delegation']._options = None
  _VALIDATOR.fields_by_name['min_self_delegation']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\322\264-\ncosmos.Int'
  _VALIDATOR._options = None
  _VALIDATOR._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _VALADDRESSES.fields_by_name['addresses']._options = None
  _VALADDRESSES.fields_by_name['addresses']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _VALADDRESSES._options = None
  _VALADDRESSES._serialized_options = b'\230\240\037\000\200\334 \001'
  _DVPAIR.fields_by_name['delegator_address']._options = None
  _DVPAIR.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DVPAIR.fields_by_name['validator_address']._options = None
  _DVPAIR.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DVPAIR._options = None
  _DVPAIR._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _DVPAIRS.fields_by_name['pairs']._options = None
  _DVPAIRS.fields_by_name['pairs']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _DVVTRIPLET.fields_by_name['delegator_address']._options = None
  _DVVTRIPLET.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DVVTRIPLET.fields_by_name['validator_src_address']._options = None
  _DVVTRIPLET.fields_by_name['validator_src_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DVVTRIPLET.fields_by_name['validator_dst_address']._options = None
  _DVVTRIPLET.fields_by_name['validator_dst_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DVVTRIPLET._options = None
  _DVVTRIPLET._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _DVVTRIPLETS.fields_by_name['triplets']._options = None
  _DVVTRIPLETS.fields_by_name['triplets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _DELEGATION.fields_by_name['delegator_address']._options = None
  _DELEGATION.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DELEGATION.fields_by_name['validator_address']._options = None
  _DELEGATION.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DELEGATION.fields_by_name['shares']._options = None
  _DELEGATION.fields_by_name['shares']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _DELEGATION._options = None
  _DELEGATION._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _UNBONDINGDELEGATION.fields_by_name['delegator_address']._options = None
  _UNBONDINGDELEGATION.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _UNBONDINGDELEGATION.fields_by_name['validator_address']._options = None
  _UNBONDINGDELEGATION.fields_by_name['validator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _UNBONDINGDELEGATION.fields_by_name['entries']._options = None
  _UNBONDINGDELEGATION.fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _UNBONDINGDELEGATION._options = None
  _UNBONDINGDELEGATION._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _UNBONDINGDELEGATIONENTRY.fields_by_name['completion_time']._options = None
  _UNBONDINGDELEGATIONENTRY.fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _UNBONDINGDELEGATIONENTRY.fields_by_name['initial_balance']._options = None
  _UNBONDINGDELEGATIONENTRY.fields_by_name['initial_balance']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\322\264-\ncosmos.Int'
  _UNBONDINGDELEGATIONENTRY.fields_by_name['balance']._options = None
  _UNBONDINGDELEGATIONENTRY.fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\322\264-\ncosmos.Int'
  _UNBONDINGDELEGATIONENTRY._options = None
  _UNBONDINGDELEGATIONENTRY._serialized_options = b'\230\240\037\000\350\240\037\001'
  _REDELEGATIONENTRY.fields_by_name['completion_time']._options = None
  _REDELEGATIONENTRY.fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _REDELEGATIONENTRY.fields_by_name['initial_balance']._options = None
  _REDELEGATIONENTRY.fields_by_name['initial_balance']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\322\264-\ncosmos.Int'
  _REDELEGATIONENTRY.fields_by_name['shares_dst']._options = None
  _REDELEGATIONENTRY.fields_by_name['shares_dst']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _REDELEGATIONENTRY._options = None
  _REDELEGATIONENTRY._serialized_options = b'\230\240\037\000\350\240\037\001'
  _REDELEGATION.fields_by_name['delegator_address']._options = None
  _REDELEGATION.fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _REDELEGATION.fields_by_name['validator_src_address']._options = None
  _REDELEGATION.fields_by_name['validator_src_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _REDELEGATION.fields_by_name['validator_dst_address']._options = None
  _REDELEGATION.fields_by_name['validator_dst_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _REDELEGATION.fields_by_name['entries']._options = None
  _REDELEGATION.fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _REDELEGATION._options = None
  _REDELEGATION._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _PARAMS.fields_by_name['unbonding_time']._options = None
  _PARAMS.fields_by_name['unbonding_time']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _PARAMS.fields_by_name['min_commission_rate']._options = None
  _PARAMS.fields_by_name['min_commission_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\032yaml:\"min_commission_rate\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000\350\240\037\001\212\347\260*\033cosmos-sdk/x/staking/Params'
  _DELEGATIONRESPONSE.fields_by_name['delegation']._options = None
  _DELEGATIONRESPONSE.fields_by_name['delegation']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _DELEGATIONRESPONSE.fields_by_name['balance']._options = None
  _DELEGATIONRESPONSE.fields_by_name['balance']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _DELEGATIONRESPONSE._options = None
  _DELEGATIONRESPONSE._serialized_options = b'\230\240\037\000\350\240\037\000'
  _REDELEGATIONENTRYRESPONSE.fields_by_name['redelegation_entry']._options = None
  _REDELEGATIONENTRYRESPONSE.fields_by_name['redelegation_entry']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _REDELEGATIONENTRYRESPONSE.fields_by_name['balance']._options = None
  _REDELEGATIONENTRYRESPONSE.fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\322\264-\ncosmos.Int'
  _REDELEGATIONENTRYRESPONSE._options = None
  _REDELEGATIONENTRYRESPONSE._serialized_options = b'\350\240\037\001'
  _REDELEGATIONRESPONSE.fields_by_name['redelegation']._options = None
  _REDELEGATIONRESPONSE.fields_by_name['redelegation']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _REDELEGATIONRESPONSE.fields_by_name['entries']._options = None
  _REDELEGATIONRESPONSE.fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _REDELEGATIONRESPONSE._options = None
  _REDELEGATIONRESPONSE._serialized_options = b'\350\240\037\000'
  _POOL.fields_by_name['not_bonded_tokens']._options = None
  _POOL.fields_by_name['not_bonded_tokens']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\352\336\037\021not_bonded_tokens\322\264-\ncosmos.Int\250\347\260*\001'
  _POOL.fields_by_name['bonded_tokens']._options = None
  _POOL.fields_by_name['bonded_tokens']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\352\336\037\rbonded_tokens\322\264-\ncosmos.Int\250\347\260*\001'
  _POOL._options = None
  _POOL._serialized_options = b'\350\240\037\001\360\240\037\001'
  _VALIDATORUPDATES.fields_by_name['updates']._options = None
  _VALIDATORUPDATES.fields_by_name['updates']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_BONDSTATUS']._serialized_start=4918
  _globals['_BONDSTATUS']._serialized_end=5100
  _globals['_INFRACTION']._serialized_start=5102
  _globals['_INFRACTION']._serialized_end=5195
  _globals['_HISTORICALINFO']._serialized_start=316
  _globals['_HISTORICALINFO']._serialized_end=447
  _globals['_COMMISSIONRATES']._serialized_start=450
  _globals['_COMMISSIONRATES']._serialized_end=720
  _globals['_COMMISSION']._serialized_start=723
  _globals['_COMMISSION']._serialized_end=891
  _globals['_DESCRIPTION']._serialized_start=893
  _globals['_DESCRIPTION']._serialized_end=1011
  _globals['_VALIDATOR']._serialized_start=1014
  _globals['_VALIDATOR']._serialized_end=1779
  _globals['_VALADDRESSES']._serialized_start=1781
  _globals['_VALADDRESSES']._serialized_end=1850
  _globals['_DVPAIR']._serialized_start=1853
  _globals['_DVPAIR']._serialized_end=1981
  _globals['_DVPAIRS']._serialized_start=1983
  _globals['_DVPAIRS']._serialized_end=2050
  _globals['_DVVTRIPLET']._serialized_start=2053
  _globals['_DVVTRIPLET']._serialized_end=2246
  _globals['_DVVTRIPLETS']._serialized_start=2248
  _globals['_DVVTRIPLETS']._serialized_end=2326
  _globals['_DELEGATION']._serialized_start=2329
  _globals['_DELEGATION']._serialized_end=2539
  _globals['_UNBONDINGDELEGATION']._serialized_start=2542
  _globals['_UNBONDINGDELEGATION']._serialized_end=2761
  _globals['_UNBONDINGDELEGATIONENTRY']._serialized_start=2764
  _globals['_UNBONDINGDELEGATIONENTRY']._serialized_end=3118
  _globals['_REDELEGATIONENTRY']._serialized_start=3121
  _globals['_REDELEGATIONENTRY']._serialized_end=3471
  _globals['_REDELEGATION']._serialized_start=3474
  _globals['_REDELEGATION']._serialized_end=3740
  _globals['_PARAMS']._serialized_start=3743
  _globals['_PARAMS']._serialized_end=4059
  _globals['_DELEGATIONRESPONSE']._serialized_start=4062
  _globals['_DELEGATIONRESPONSE']._serialized_end=4214
  _globals['_REDELEGATIONENTRYRESPONSE']._serialized_start=4217
  _globals['_REDELEGATIONENTRYRESPONSE']._serialized_end=4411
  _globals['_REDELEGATIONRESPONSE']._serialized_start=4414
  _globals['_REDELEGATIONRESPONSE']._serialized_end=4592
  _globals['_POOL']._serialized_start=4595
  _globals['_POOL']._serialized_end=4833
  _globals['_VALIDATORUPDATES']._serialized_start=4835
  _globals['_VALIDATORUPDATES']._serialized_end=4915
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/oracle.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/oracle/v1beta1/oracle.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"%\n\x06Params\x12\x15\n\rpyth_contract\x18\x01 \x01(\t:\x04\xe8\xa0\x1f\x01\"W\n\nOracleInfo\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x39\n\x0boracle_type\x18\x02 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\"\xba\x01\n\x13\x43hainlinkPriceState\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12>\n\x06\x61nswer\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12?\n\x0bprice_state\x18\x04 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"\xc9\x01\n\x0e\x42\x61ndPriceState\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12<\n\x04rate\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x14\n\x0cresolve_time\x18\x03 \x01(\x04\x12\x12\n\nrequest_ID\x18\x04 \x01(\x04\x12?\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"z\n\x0ePriceFeedState\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\x12\x39\n\x0bprice_state\x18\x03 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\x12\x10\n\x08relayers\x18\x04 \x03(\t\"2\n\x0cProviderInfo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x10\n\x08relayers\x18\x02 \x03(\t\"\x9b\x01\n\rProviderState\x12=\n\rprovider_info\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.ProviderInfo\x12K\n\x15provider_price_states\x18\x02 \x03(\x0b\x32,.injective.oracle.v1beta1.ProviderPriceState\"Y\n\x12ProviderPriceState\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x33\n\x05state\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceState\",\n\rPriceFeedInfo\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\"O\n\x0ePriceFeedPrice\x12=\n\x05price\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\x92\x01\n\x12\x43oinbasePriceState\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\x04\x12?\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"\xa8\x01\n\nPriceState\x12=\n\x05price\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12H\n\x10\x63umulative_price\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"\xbc\x02\n\x0ePythPriceState\x12\x10\n\x08price_id\x18\x01 \x01(\t\x12\x41\n\tema_price\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12@\n\x08\x65ma_conf\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12<\n\x04\x63onf\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x14\n\x0cpublish_time\x18\x05 \x01(\x04\x12?\n\x0bprice_state\x18\x06 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00\"\x9c\x02\n\x11\x42\x61ndOracleRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x04\x12\x18\n\x10oracle_script_id\x18\x02 \x01(\x03\x12\x0f\n\x07symbols\x18\x03 \x03(\t\x12\x11\n\task_count\x18\x04 \x01(\x04\x12\x11\n\tmin_count\x18\x05 \x01(\x04\x12^\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x13\n\x0bprepare_gas\x18\x07 \x01(\x04\x12\x13\n\x0b\x65xecute_gas\x18\x08 \x01(\x04\x12\x18\n\x10min_source_count\x18\t \x01(\x04\"\xa8\x01\n\rBandIBCParams\x12\x18\n\x10\x62\x61nd_ibc_enabled\x18\x01 \x01(\x08\x12\x1c\n\x14ibc_request_interval\x18\x02 \x01(\x03\x12\x1a\n\x12ibc_source_channel\x18\x03 \x01(\t\x12\x13\n\x0bibc_version\x18\x04 \x01(\t\x12\x13\n\x0bibc_port_id\x18\x05 \x01(\t\x12\x19\n\x11legacy_oracle_ids\x18\x06 \x03(\x03\"r\n\x14SymbolPriceTimestamp\x12\x34\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x11\n\tsymbol_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"d\n\x13LastPriceTimestamps\x12M\n\x15last_price_timestamps\x18\x01 \x03(\x0b\x32..injective.oracle.v1beta1.SymbolPriceTimestamp\"\x9c\x01\n\x0cPriceRecords\x12\x34\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x11\n\tsymbol_id\x18\x02 \x01(\t\x12\x43\n\x14latest_price_records\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecord\"_\n\x0bPriceRecord\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12=\n\x05price\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\xbf\x03\n\x12MetadataStatistics\x12\x13\n\x0bgroup_count\x18\x01 \x01(\r\x12\x1b\n\x13records_sample_size\x18\x02 \x01(\r\x12<\n\x04mean\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12<\n\x04twap\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x17\n\x0f\x66irst_timestamp\x18\x05 \x01(\x03\x12\x16\n\x0elast_timestamp\x18\x06 \x01(\x03\x12\x41\n\tmin_price\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x41\n\tmax_price\x18\x08 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x44\n\x0cmedian_price\x18\t \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\x9c\x01\n\x10PriceAttestation\x12\x10\n\x08price_id\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x03\x12\x0c\n\x04\x63onf\x18\x03 \x01(\x04\x12\x0c\n\x04\x65xpo\x18\x04 \x01(\x05\x12\x11\n\tema_price\x18\x05 \x01(\x03\x12\x10\n\x08\x65ma_conf\x18\x06 \x01(\x04\x12\x10\n\x08\x65ma_expo\x18\x07 \x01(\x05\x12\x14\n\x0cpublish_time\x18\x08 \x01(\x03*\x9f\x01\n\nOracleType\x12\x0f\n\x0bUnspecified\x10\x00\x12\x08\n\x04\x42\x61nd\x10\x01\x12\r\n\tPriceFeed\x10\x02\x12\x0c\n\x08\x43oinbase\x10\x03\x12\r\n\tChainlink\x10\x04\x12\t\n\x05Razor\x10\x05\x12\x07\n\x03\x44ia\x10\x06\x12\x08\n\x04\x41PI3\x10\x07\x12\x07\n\x03Uma\x10\x08\x12\x08\n\x04Pyth\x10\t\x12\x0b\n\x07\x42\x61ndIBC\x10\n\x12\x0c\n\x08Provider\x10\x0b\x42RZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xc0\xe3\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.oracle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\300\343\036\001'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001'
  _CHAINLINKPRICESTATE.fields_by_name['answer']._options = None
  _CHAINLINKPRICESTATE.fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _CHAINLINKPRICESTATE.fields_by_name['price_state']._options = None
  _CHAINLINKPRICESTATE.fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _BANDPRICESTATE.fields_by_name['rate']._options = None
  _BANDPRICESTATE.fields_by_name['rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _BANDPRICESTATE.fields_by_name['price_state']._options = None
  _BANDPRICESTATE.fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _PRICEFEEDPRICE.fields_by_name['price']._options = None
  _PRICEFEEDPRICE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _COINBASEPRICESTATE.fields_by_name['price_state']._options = None
  _COINBASEPRICESTATE.fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _PRICESTATE.fields_by_name['price']._options = None
  _PRICESTATE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PRICESTATE.fields_by_name['cumulative_price']._options = None
  _PRICESTATE.fields_by_name['cumulative_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PYTHPRICESTATE.fields_by_name['ema_price']._options = None
  _PYTHPRICESTATE.fields_by_name['ema_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PYTHPRICESTATE.fields_by_name['ema_conf']._options = None
  _PYTHPRICESTATE.fields_by_name['ema_conf']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PYTHPRICESTATE.fields_by_name['conf']._options = None
  _PYTHPRICESTATE.fields_by_name['conf']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PYTHPRICESTATE.fields_by_name['price_state']._options = None
  _PYTHPRICESTATE.fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _BANDORACLEREQUEST.fields_by_name['fee_limit']._options = None
  _BANDORACLEREQUEST.fields_by_name['fee_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _PRICERECORD.fields_by_name['price']._options = None
  _PRICERECORD.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _METADATASTATISTICS.fields_by_name['mean']._options = None
  _METADATASTATISTICS.fields_by_name['mean']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _METADATASTATISTICS.fields_by_name['twap']._options = None
  _METADATASTATISTICS.fields_by_name['twap']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _METADATASTATISTICS.fields_by_name['min_price']._options = None
  _METADATASTATISTICS.fields_by_name['min_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _METADATASTATISTICS.fields_by_name['max_price']._options = None
  _METADATASTATISTICS.fields_by_name['max_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _METADATASTATISTICS.fields_by_name['median_price']._options = None
  _METADATASTATISTICS.fields_by_name['median_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _globals['_ORACLETYPE']._serialized_start=3375
  _globals['_ORACLETYPE']._serialized_end=3534
  _globals['_PARAMS']._serialized_start=121
  _globals['_PARAMS']._serialized_end=158
  _globals['_ORACLEINFO']._serialized_start=160
  _globals['_ORACLEINFO']._serialized_end=247
  _globals['_CHAINLINKPRICESTATE']._serialized_start=250
  _globals['_CHAINLINKPRICESTATE']._serialized_end=436
  _globals['_BANDPRICESTATE']._serialized_start=439
  _globals['_BANDPRICESTATE']._serialized_end=640
  _globals['_PRICEFEEDSTATE']._serialized_start=642
  _globals['_PRICEFEEDSTATE']._serialized_end=764
  _globals['_PROVIDERINFO']._serialized_start=766
  _globals['_PROVIDERINFO']._serialized_end=816
  _globals['_PROVIDERSTATE']._serialized_start=819
  _globals['_PROVIDERSTATE']._serialized_end=974
  _globals['_PROVIDERPRICESTATE']._serialized_start=976
  _globals['_PROVIDERPRICESTATE']._serialized_end=1065
  _globals['_PRICEFEEDINFO']._serialized_start=1067
  _globals['_PRICEFEEDINFO']._serialized_end=1111
  _globals['_PRICEFEEDPRICE']._serialized_start=1113
  _globals['_PRICEFEEDPRICE']._serialized_end=1192
  _globals['_COINBASEPRICESTATE']._serialized_start=1195
  _globals['_COINBASEPRICESTATE']._serialized_end=1341
  _globals['_PRICESTATE']._serialized_start=1344
  _globals['_PRICESTATE']._serialized_end=1512
  _globals['_PYTHPRICESTATE']._serialized_start=1515
  _globals['_PYTHPRICESTATE']._serialized_end=1831
  _globals['_BANDORACLEREQUEST']._serialized_start=1834
  _globals['_BANDORACLEREQUEST']._serialized_end=2118
  _globals['_BANDIBCPARAMS']._serialized_start=2121
  _globals['_BANDIBCPARAMS']._serialized_end=2289
  _globals['_SYMBOLPRICETIMESTAMP']._serialized_start=2291
  _globals['_SYMBOLPRICETIMESTAMP']._serialized_end=2405
  _globals['_LASTPRICETIMESTAMPS']._serialized_start=2407
  _globals['_LASTPRICETIMESTAMPS']._serialized_end=2507
  _globals['_PRICERECORDS']._serialized_start=2510
  _globals['_PRICERECORDS']._serialized_end=2666
  _globals['_PRICERECORD']._serialized_start=2668
  _globals['_PRICERECORD']._serialized_end=2763
  _globals['_METADATASTATISTICS']._serialized_start=2766
  _globals['_METADATASTATISTICS']._serialized_end=3213
  _globals['_PRICEATTESTATION']._serialized_start=3216
  _globals['_PRICEATTESTATION']._serialized_end=3372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/reflection/v1/reflection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/reflection/v1/reflection.proto\x12\x14\x63osmos.reflection.v1\x1a google/protobuf/descriptor.proto\x1a\x1b\x63osmos/query/v1/query.proto\"\x18\n\x16\x46ileDescriptorsRequest\"N\n\x17\x46ileDescriptorsResponse\x12\x33\n\x05\x66iles\x18\x01 \x03(\x0b\x32$.google.protobuf.FileDescriptorProto2\x8a\x01\n\x11ReflectionService\x12u\n\x0f\x46ileDescriptors\x12,.cosmos.reflection.v1.FileDescriptorsRequest\x1a-.cosmos.reflection.v1.FileDescriptorsResponse\"\x05\x88\xe7\xb0*\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.reflection.v1.reflection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REFLECTIONSERVICE.methods_by_name['FileDescriptors']._options = None
  _REFLECTIONSERVICE.methods_by_name['FileDescriptors']._serialized_options = b'\210\347\260*\000'
  _globals['_FILEDESCRIPTORSREQUEST']._serialized_start=126
  _globals['_FILEDESCRIPTORSREQUEST']._serialized_end=150
  _globals['_FILEDESCRIPTORSRESPONSE']._serialized_start=152
  _globals['_FILEDESCRIPTORSRESPONSE']._serialized_end=230
  _globals['_REFLECTIONSERVICE']._serialized_start=233
  _globals['_REFLECTIONSERVICE']._serialized_end=371
# @@protoc_insertion_point(module_scope)



# Import first api_implementation from protobuf to force the import of architecture specific dependencies
# If this is not imported, importing later grpcio (required by AsyncClient) fails in Mac machines with M1 and M2
from google.protobuf.internal import api_implementation  # noqa: F401

from .async_client import AsyncClient  # noqa: F401
from .transaction import Transaction  # noqa: F401
from .wallet import Address, PrivateKey, PublicKey  # noqa: F401
